@@ -36,6 +36,8 @@ pub mod create_inbox_ruleset_options;
 pub use self::create_inbox_ruleset_options::CreateInboxRulesetOptions;
 pub mod create_template_options;
 pub use self::create_template_options::CreateTemplateOptions;
+pub mod create_tracking_pixel_options;
+pub use self::create_tracking_pixel_options::CreateTrackingPixelOptions;
 pub mod create_webhook_options;
 pub use self::create_webhook_options::CreateWebhookOptions;
 pub mod describe_domain_options;
@@ -96,8 +98,10 @@ pub mod inbox_projection;
 pub use self::inbox_projection::InboxProjection;
 pub mod inbox_ruleset_dto;
 pub use self::inbox_ruleset_dto::InboxRulesetDto;
-pub mod inbox_ruleset_projection;
-pub use self::inbox_ruleset_projection::InboxRulesetProjection;
+pub mod inbox_ruleset_test_options;
+pub use self::inbox_ruleset_test_options::InboxRulesetTestOptions;
+pub mod inbox_ruleset_test_result;
+pub use self::inbox_ruleset_test_result::InboxRulesetTestResult;
 pub mod ip_address_result;
 pub use self::ip_address_result::IpAddressResult;
 pub mod match_option;
@@ -128,8 +132,8 @@ pub mod page_group_projection;
 pub use self::page_group_projection::PageGroupProjection;
 pub mod page_inbox_projection;
 pub use self::page_inbox_projection::PageInboxProjection;
-pub mod page_inbox_ruleset_projection;
-pub use self::page_inbox_ruleset_projection::PageInboxRulesetProjection;
+pub mod page_inbox_ruleset_dto;
+pub use self::page_inbox_ruleset_dto::PageInboxRulesetDto;
 pub mod page_missed_email_projection;
 pub use self::page_missed_email_projection::PageMissedEmailProjection;
 pub mod page_organization_inbox_projection;
@@ -140,6 +144,8 @@ pub mod page_template_projection;
 pub use self::page_template_projection::PageTemplateProjection;
 pub mod page_thread_projection;
 pub use self::page_thread_projection::PageThreadProjection;
+pub mod page_tracking_pixel_projection;
+pub use self::page_tracking_pixel_projection::PageTrackingPixelProjection;
 pub mod page_webhook_projection;
 pub use self::page_webhook_projection::PageWebhookProjection;
 pub mod page_webhook_result;
@@ -170,8 +176,14 @@ pub mod template_projection;
 pub use self::template_projection::TemplateProjection;
 pub mod template_variable;
 pub use self::template_variable::TemplateVariable;
+pub mod test_new_inbox_ruleset_options;
+pub use self::test_new_inbox_ruleset_options::TestNewInboxRulesetOptions;
 pub mod thread_projection;
 pub use self::thread_projection::ThreadProjection;
+pub mod tracking_pixel_dto;
+pub use self::tracking_pixel_dto::TrackingPixelDto;
+pub mod tracking_pixel_projection;
+pub use self::tracking_pixel_projection::TrackingPixelProjection;
 pub mod unread_count;
 pub use self::unread_count::UnreadCount;
 pub mod update_alias_options;
@@ -194,6 +206,8 @@ pub mod wait_for_conditions;
 pub use self::wait_for_conditions::WaitForConditions;
 pub mod webhook_dto;
 pub use self::webhook_dto::WebhookDto;
+pub mod webhook_email_opened_payload;
+pub use self::webhook_email_opened_payload::WebhookEmailOpenedPayload;
 pub mod webhook_new_attachment_payload;
 pub use self::webhook_new_attachment_payload::WebhookNewAttachmentPayload;
 pub mod webhook_new_contact_payload;
